<?php
// Classes and libraries for module system
//
// webtrees: Web based Family History software
// Copyright (C) 2012 webtrees development team.
// Derived from PhpGedView
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
//
// Module Display ressources - Copyright (C) 2012 André DUMAS

/*
*	See changelog.txt
*/

namespace Andre\WebtreesAddOn\Ressources;

use Composer\Autoload\ClassLoader;
use Fisharebest\Webtrees\Database;
use Fisharebest\Webtrees\Filter;
use Fisharebest\Webtrees\I18N;
use Fisharebest\Webtrees\Auth;
use Fisharebest\Webtrees\Log;
use Fisharebest\Webtrees\Module\AbstractModule;
use Fisharebest\Webtrees\Module\ModuleConfigInterface;
use Fisharebest\Webtrees\Module\ModuleSidebarInterface;
use Fisharebest\Webtrees\Module\ModuleTabInterface;
use Fisharebest\Webtrees\Controller\PageController;


class ressourcesModule extends AbstractModule implements ModuleConfigInterface, ModuleTabInterface {
	const  CUSTOM_VERSIOn = 'V-1-7-7-1';
	const  DATA_LAST_CHANGE = '2016-07-31';
	
	var $target_version = 2;
	
	// = = = = = = = = = = = = = = = =
	public function __construct() {
		parent::__construct(__DIR__);
	
		// register the namespaces
		$loader = new ClassLoader();
		$loader->addPsr4('Andre\\WebtreesAddOn\\Ressources\\', WT_MODULES_DIR . $this->getName() . '/src');
		$loader->register();
		
			// Update the database tables if neccessary.
		Database::updateSchema('\Andre\WebtreesAddOn\Ressources\Schema', 'RESSOURCE_SCHEMA_VERSION', $this->target_version);	
		
	
	}

	private function module() {
		return new ressourcesClass;
	}	

	// = = = = = = = = = = = = = = = =
	public function getTitle()	{
				$title = 'Ressources';
			return $title;
				
	}

	// = = = = = = = = = = = = = = = =
	public function getDescription() {
		return I18N::translate('A Tab showing ressources for this id.');
	}

	// = = = = = = = = = = = = = = = =
	public function defaultTabOrder() {
		return 50;
	}

	public function canLoadAjax() {
	global $SEARCH_SPIDER;
		return !$SEARCH_SPIDER; // Search engines cannot use AJAX
	} 
	
	public function getPreLoadContent() {
	return '';
	}
	
	public function isGrayedOut() {
	return '';
	}
	
	
	// = = = = = = = = = = = = = = = =
	public function hasTabContent() {
		return true;
	}

	// = = = = = = = = = = = = = = = =
	public function getTabContent()	{
		global $controller, $show_full, $edit, $GEDCOM, $pid, $WT_TREE;
		$show_full = "1";
		
		$gidd = $WT_TREE->getName(); //WT_GEDCOM  nom du gedcom courant
		$gidnum = $WT_TREE->getTreeId(); // numéro du gedcom courant
		// controller donne les infos sur le $pid courant ci-dessus
		$xs = $controller->record->getFullName();
		$xss = $controller->record->getXref();
		$rid = $WT_TREE->getPreference('PEDIGREE_ROOT_ID', $default_value = null);
		;
include('search.inc.php');

echo $style='<style>
button {
	background-color:lightgrey;
	border-radius:5px;
}
</style>';
	//= = = = = = = = = = = = = = = = = = = = = = = = = =	
	// Changer le titre
	//= = = = = = = = = = = = = = = = = = = = = = = = = =
	$controller ->addInlineJavascript('
						$("a#portrait").RessourceIdBox({
							
						});
	');
	
	
	$res_perso  = array();  //ressources de l'Id
	$res_nat    = array();  // ressources nationales
	$res_dept   = array();   // ressources départementales
	
	// vars intermédiaires
	$data = array(array());
	$p = array();
	$d = array();
	$n = array();
	$no = array();
	
	$locs_array = array(array());
	$s = array(array());
	
	
	// get le département (s) courant
	$places = array(); //lieux associés aux évènements
	foreach ($controller->record->getFacts() as $fact) {
			if (!($fact->getPlace()->isEmpty())) {
				$places[] = $fact->getPlace()->getGedcomName();
			}
	};  //foreach $places plein
	
	// lieux français avec 4 champs , 1 seul champ pour commune et code INSEE ce qui est particulier voir module French-tools
	$noplace = true;
	
	if (!empty($places)) {	$noplace= false; //il y a des lieux

		foreach ($places as $lieu) {  //tableau des lieux dans $locs_array
				 if (!empty($lieu)) { $locs_array[] = explode(",", $lieu);}
		}		
	}		

	if (!empty($locs_array)) {	//on travaille sur le tableau des lieux
		foreach ($locs_array as $location) {
			if (empty($location)) {continue;}
			
			$num = substr(trim(substr(trim($location[0]),-6)),0,2); //n° dept
			$pais = trim($location[3]); //pays
			$nam =substr(trim($location[0]),0, strlen(trim($location[0]))-6); //nom de" ville 
			$det =  trim($location[1]); // dept
			
	// Villes étrangères : leur affecter un insee fictif pour être à la norme adoptée pour fr mais permettant de les distinguer 1x ou 99 par exemple		
			if ( (!in_array($num, $no)) || (!in_array($pais, $p)) || ( (!in_array($num, $no)) && (!in_array($pais, $p))) )	{
					$no[] = $num;  //n° insee
					$p[]  = $pais;  //pays
					$d[]  = trim($location[1]);
					$n[]  = $nam;
					
					$t[] =  array('nom' => $nam, 'num' => $num , 'dept' => $det, 'pays' => $pais) ;
					
			} //else {exit(); }// ajouter le bouton "ajouter ressource spour id"}
		 
		
		}

	if (count($p) != 0) {	
		// res nat
		foreach (array_unique($p) as $pays) {
				$ressources = $this->module()->getRessources('00', trim($pays));
								foreach ($ressources as $ressource) {
									if ((!empty($ressource)) && (($ressource->res_xref == '') || ($ressource->res_xref == NULL)) ) {
										if ($this->module()->displayRes($ressource) ){
										$res_nat[] = $ressource;
										}
									} 
								}

			foreach ($no as $num) { 
				$ressources = $this->module()->getRessources($num, trim($pays));
				foreach ($ressources as $ressource) {
					if ((!empty($ressource)) && (trim($ressource->res_pays) == trim($pays)) && ($ressource->res_dept == $num) && (($ressource->res_xref == '') || ($ressource->res_xref == NULL)) ) {
						if ($this->module()->displayRes($ressource) ){
							$res_dept[] = $ressource;
						}	
					} 
				} // each res	
			} //each no
	} // each p
	
		
	} //if count
		
	 
} // fin de ln if (!empty($places)) 

// ressources perso
		$ressources = $this->module()->getRessources('','');
		foreach ($ressources as $ressource) {
				if ((!empty($ressource)) && ($ressource->res_xref == $pid)) {	
					if ($this->module()->displayRes($ressource) ){
						$res_perso[] = $ressource;
					}	
				} //if
		}
	
// sortie affichage

		$out = '<div id="nav_content" id="resmodule" style="padding:20px;">
					<div style="padding:2px;width:85%;">'.$WindowSearchInc;
		ob_start();
		
	// = = = = = = = = = = = = 
	// Boucle d'affichage
	// = = = = = = = = = = = = 
	//include('search.inc.php');
			
		echo '<button><h2><i>Ressources utiles ou utilisées pour cette personne</i></h2></button>';
		
		
	if (!$noplace) { 	
		//Ressources nationales
		$ligne = '';
		$tmpp = '';

	
	
	echo '<fieldset><legend>Ressources nationales</legend>
	<table>';	
	foreach ($res_nat as $resn) { 
		      
	if ((trim($resn->res_pays) != $tmpp)) {echo '<button>'.$resn->res_pays .'</button>';$tmpp = $resn->res_pays;}			 
		
		$ligne ='<tr>
		<td><p> 
		<div title="'.$resn->res_note.'">
		<a href="'.$resn->res_lk.'">'.$resn->res_name.' </a>
		</div></p></td>
		<td>
		<p style=" color:'.$this->module()->aff_statut($resn->res_gratuit).'" >'.$resn->res_type.'  '.$resn->res_gratuit.'</p>
		</td>
		<td>'.$this->module()->aff_avis($resn->res_appreciation).'</td></tr>';
	  echo $ligne; 
	  
	  $ligne = '';
	}  //foreach resn
		echo '</table></fieldset>';
		
	//res dept
		$ligne = '';
		$tmpp = '';
		//Ressources départementales
		echo '
		<fieldset><legend>Ressources départementales</legend>
		<table>';
		  foreach ($res_dept as $resd) {
		  if ((trim($resd->res_dept) != $tmpp)) {$ln = '<th><button>'.$resd->res_dept .'</button></th>';$tmpp = $resd->res_dept;} else {$ln = '';}
		$ligne =$ln.'
		<tr>
			<td><p> 
			<div title="'.$resd->res_note.'">
			<a href="'.$resd->res_lk.'">'.$resd->res_name.' </a>
			</div></p>
			</td>
			<td>
			<p style=" color:'.$this->module()->aff_statut($resd->res_gratuit).'" >'.$resd->res_type.'  '.$resd->res_gratuit.'</p>
			</td>
			<td>'.$this->module()->aff_avis($resd->res_appreciation).
			'</td>
		</tr>';
		
		echo $ligne;
		}
		echo '</table></fieldset>';
		

	}

	//Ressources individuelles
			$ligne = '';
		echo '
		<fieldset id="persoRef"><legend>
		<button >Ressources propres à cet individu</button>
					</legend>';
		  foreach ($res_perso as $resp) {
		$ligne .= '<p> 
		<div class="res_perso" title="'.$resp->res_note.'">
		<a href="'.$resp->res_lk.'">'.$resp->res_name.' </a>
		</div></p>
		';
		  }
		  
		echo $ligne;
		
		echo '';
		echo '</fieldset>';
		
		// = = = = = = = = = = = = 
		// fin affichage ressources
		// = = = = = = = = = = = = 
		// = = = = = = = = = = = = 
		// si admin ouverture de popup pour entrer des ressources relatives a id courant
		// = = = = = = = = = = = = 
		// Utiliser Ajax pour mettre à jour la page après nouvelle entrée
		if(Auth::isAdmin()) {
			echo '<p> 				<!--ouvrir popup -->
			    <button  onClick="window.open(\'module.php?mod='.$this->getName().'&mod_action=add_ressources&pid='.$pid.'\',\'Fiche\',\'toolbar=no,status=no,width=440 ,height=400,scrollbars=yes,location=no,resize=yes,menubar=yes\')"
                  > Ajouter une ressource spécifique à cet id</button>			
		</p>';
		}
		
		echo '<br><br><br>';
		
		// rafraichir et fermer popup :     <input type="button" value="fermer" onclick="javascript:parent.opener.location.reload();window.close();">
		// = = = = = = = = = = = = 
		$out.= ob_get_clean().'</div></div>';
		
		return $out;
} // fin getSidebarContent

	// = = = = = = = = = = = = = = = =

	// = = = = = = = = = = = = = = = =	
// Implement WT_Module_Config
	public function getConfigLink() {
		return 'module.php?mod='.$this->getName().'&amp;mod_action=admin_ressources';
	}	
	
		// = = = = = = = = = = = = = = = =
		// Administration des événements
	private function admin_ressources() {
	
	global $WT_TREE, $pid ;
	
if (!(Auth::isAdmin())) { exit();}			
	
		$xref = '';
		$email='';
		$gid = $WT_TREE->getTreeId();
				
if ((null != Filter::post('url')) && (null != Filter::post('res_name')) ) {
    //inout event
	$pays = Filter::post('list_pays'); //nom du chef pour ev
	$url = Filter::post('url');  //nom du chef pour ev
	$note = Filter::post('note');  //nom du chef pour ev
	$dept = Filter::post('dep'); //nom du chef pour ev
	$app = Filter::post('app');
	$gr = Filter::post('gr');
	$type = Filter::post('res_type'); 
	$email = Filter::post('mail');
	$statut = Filter::post('res_statut'); 
	$nom = Filter::post('res_name'); 
	
		$this->module()->insert_res($url,  $note, $statut, $type, $app, $email, $gr, $pays, $dept, $xref, $gid, $nom);
	}
	
	$this->module()->formulaire_add_res('');
	}
	   // = = = = = = = = = = = = = = = =

	// = = = = = = = = = = = = = = = =
	public function modAction($mod_action) {
		
		switch ($mod_action) {
		case 'admin_ressources':
			$this->admin_ressources();
			break;
		case 'add_ressources':	
			$pid = Filter::get('pid');
			$this->module()->add_ressources($pid);
			break;	
					
		default:
echo '<br>⁂ Erreur dans la fonction modAction : mod_action = ' . $mod_action . '<br>'; break;
//			header('HTTP/1.0 404 Not Found');
		}
	}

	// = = = = = = = = = = = = = = = =
	// Implement WT_Module_Tab
	public function getJSCallback() {	
	return '';
	}

   
}

return new ressourcesModule;
